@@ -13,21 +13,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron.callbacks import events
-from neutron.callbacks import registry
-from neutron.callbacks import resources
 from neutron.db import servicetype_db as st_db
 from neutron.services import provider_configuration as pconf
 from neutron.services import service_base
 
+from neutron_lib.api.definitions import bgpvpn as bgpvpn_def
+from neutron_lib.callbacks import events
+from neutron_lib.callbacks import registry
+from neutron_lib.callbacks import resources
 from neutron_lib import constants as const
 from neutron_lib import exceptions as n_exc
+from neutron_lib.plugins import constants as plugin_constants
 from neutron_lib.plugins import directory
 
 from oslo_log import log
 
-from networking_bgpvpn._i18n import _LI
-from networking_bgpvpn._i18n import _LW
+from networking_bgpvpn._i18n import _
 
 from networking_bgpvpn.neutron.extensions import bgpvpn
 from networking_bgpvpn.neutron.services.common import constants
@@ -46,20 +47,20 @@ class BGPVPNPlugin(bgpvpn.BGPVPNPluginBase):
         # service_provider definitions:
         service_type_manager = st_db.ServiceTypeManager.get_instance()
         service_type_manager.add_provider_configuration(
-            constants.BGPVPN,
+            bgpvpn_def.LABEL,
             pconf.ProviderConfiguration('networking_bgpvpn'))
 
         # Load the default driver
-        drivers, default_provider = service_base.load_drivers(constants.BGPVPN,
+        drivers, default_provider = service_base.load_drivers(bgpvpn_def.LABEL,
                                                               self)
-        LOG.info(_LI("BGP VPN Service Plugin using Service Driver: %s"),
+        LOG.info("BGP VPN Service Plugin using Service Driver: %s",
                  default_provider)
         self.driver = drivers[default_provider]
 
         if len(drivers) > 1:
-            LOG.warning(_LW("Multiple drivers configured for BGPVPN, although"
-                            "running multiple drivers in parallel is not yet"
-                            "supported"))
+            LOG.warning("Multiple drivers configured for BGPVPN, although"
+                        "running multiple drivers in parallel is not yet"
+                        "supported")
         registry.subscribe(self._notify_adding_interface_to_router,
                            resources.ROUTER_INTERFACE,
                            events.BEFORE_CREATE)
@@ -117,7 +118,7 @@ class BGPVPNPlugin(bgpvpn.BGPVPNPluginBase):
                 raise n_exc.BadRequest(resource='bgpvpn', msg=msg)
 
     def _validate_router(self, context, router_id):
-        l3_plugin = directory.get_plugin(const.L3)
+        l3_plugin = directory.get_plugin(plugin_constants.L3)
         router = l3_plugin.get_router(context, router_id)
         plugin = directory.get_plugin()
         self._validate_router_has_net_assocs(context, router, plugin)
@@ -143,7 +144,7 @@ class BGPVPNPlugin(bgpvpn.BGPVPNPluginBase):
                     raise n_exc.BadRequest(resource='bgpvpn', msg=msg)
 
     def get_plugin_type(self):
-        return constants.BGPVPN
+        return bgpvpn_def.LABEL
 
     def get_plugin_description(self):
         return "Neutron BGPVPN Service Plugin"
