@@ -16,15 +16,15 @@
 from sqlalchemy import orm
 from sqlalchemy import sql
 
-from neutron.callbacks import events
-from neutron.callbacks import registry
-from neutron.callbacks import resources
-from neutron.db import external_net_db
-from neutron.db import l3_db
+from neutron.db.models import external_net
+from neutron.db.models import l3
 from neutron.db import models_v2
 from neutron.debug import debug_agent
 
 from neutron_lib.api.definitions import portbindings
+from neutron_lib.callbacks import events
+from neutron_lib.callbacks import registry
+from neutron_lib.callbacks import resources
 from neutron_lib import constants as const
 from neutron_lib import exceptions as n_exc
 
@@ -33,8 +33,6 @@ from oslo_log import log as logging
 
 from networking_bagpipe.agent.bgpvpn import rpc_client
 
-from networking_bgpvpn._i18n import _LE
-
 from networking_bgpvpn.neutron.db import bgpvpn_db
 from networking_bgpvpn.neutron.extensions import bgpvpn as bgpvpn_ext
 from networking_bgpvpn.neutron.services.common import constants
@@ -148,8 +146,8 @@ def get_bgpvpns_of_router_assocs_by_network(context, net_id):
         context.session.query(bgpvpn_db.BGPVPN).
         join(bgpvpn_db.BGPVPN.router_associations).
         join(bgpvpn_db.BGPVPNRouterAssociation.router).
-        join(l3_db.Router.attached_ports).
-        join(l3_db.RouterPort.port).
+        join(l3.Router.attached_ports).
+        join(l3.RouterPort.port).
         filter(
             models_v2.Port.network_id == net_id
         ).all()
@@ -158,7 +156,7 @@ def get_bgpvpns_of_router_assocs_by_network(context, net_id):
 
 def network_is_external(context, net_id):
     try:
-        context.session.query(external_net_db.ExternalNetwork).filter_by(
+        context.session.query(external_net.ExternalNetwork).filter_by(
             network_id=net_id).one()
         return True
     except orm.exc.NoResultFound:
@@ -166,9 +164,9 @@ def network_is_external(context, net_id):
 
 
 def _log_callback_processing_exception(resource, event, trigger, kwargs, e):
-    LOG.exception(_LE("Error during notification processing "
-                      "%(resource)s %(event)s, %(trigger)s, "
-                      "%(kwargs)s: %(exc)s"),
+    LOG.exception("Error during notification processing "
+                  "%(resource)s %(event)s, %(trigger)s, "
+                  "%(kwargs)s: %(exc)s",
                   {'trigger': trigger,
                    'resource': resource,
                    'event': event,
